@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2015-04-07'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2015-06-16'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010;
 use strict;
@@ -65,7 +65,7 @@ sub cmdline_src_stdin_array {
 
 $SPEC{cmdline_src_file} = {
     v => 1.1,
-    summary => 'This function has args with cmdline_src _file',
+    summary => 'This function has args with cmdline_src=file',
     args => {
         a1 => {schema=>'str*', req=>1, cmdline_src=>'file'},
         a2 => {schema=>'array*', cmdline_src=>'file'},
@@ -213,14 +213,14 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.52 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-04-07.
+This document describes version 0.53 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-06-16.
 
 =head1 FUNCTIONS
 
 
 =head2 cmdline_src_file(%args) -> [status, msg, result, meta]
 
-This function has args with cmdline_src _file.
+This function has args with cmdline_src=file.
 
 Arguments ('*' denotes required arguments):
 
